package com.proyecto.libroinmersiones;

import android.app.AlertDialog;
import android.app.ListActivity;
import android.content.DialogInterface;
import android.content.Intent;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Bundle;
import android.support.v4.widget.SimpleCursorAdapter;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.EditText;
import android.widget.ListView;

public class ListaInmersiones extends ListActivity implements LocationListener {

	public AdaptadorCursorInmersiones adaptador;
	private LocationManager manejador;
	private Location mejorLocaliz;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.inmersiones);
		// adaptador = new AdaptadorDives(this);
		CentrosBuceo.inicializaBD(this);
		Inmersiones.inicializaBD(this);
		adaptador = new AdaptadorCursorInmersiones(this, Inmersiones.listado());
		setListAdapter(adaptador);

		manejador = (LocationManager) getSystemService(LOCATION_SERVICE);
		if (manejador.isProviderEnabled(LocationManager.GPS_PROVIDER)) {
			actualizaMejorLocaliz(manejador
					.getLastKnownLocation(LocationManager.GPS_PROVIDER));
		}
		if (manejador.isProviderEnabled(LocationManager.NETWORK_PROVIDER)) {
			actualizaMejorLocaliz(manejador
					.getLastKnownLocation(LocationManager.NETWORK_PROVIDER));
		}

	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.menu_lista, menu);

		return true;
		/** true -> el men ya est visible */
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {

		case R.id.menu_buscar:
			lanzarVistaInmersion(null);
			break;
		case R.id.menu_mapa:
			Intent intent = new Intent(this, Mapa.class);
			 intent.putExtra("tipo_mapa", 1);
			startActivityForResult(intent,0);
			break;
		case R.id.accion_nueva:
			long id = Inmersiones.nuevo();
			Intent i = new Intent(this, EdicionInmersion.class);
			i.putExtra("id", id);
			startActivityForResult(i,0);
			return true;
		}
		return true;
		/** true -> consumimos el item, no se propaga */
	}

	public void lanzarVistaInmersion(View view) {
		final EditText entrada = new EditText(this);
		entrada.setText("0");
		new AlertDialog.Builder(this).setTitle("Seleccin de lugar")
				.setMessage("indica su id:").setView(entrada)
				.setPositiveButton("Ok", new DialogInterface.OnClickListener() {
					public void onClick(DialogInterface dialog, int whichButton) {
						long id = Long.parseLong(entrada.getText().toString());
						Intent i = new Intent(ListaInmersiones.this,
								VistaInmersion.class);
						i.putExtra("id", id);
						startActivity(i);
					}
				}).setNegativeButton("Cancelar", null).show();
	}

	@Override
	protected void onListItemClick(ListView listView, View vista, int posicion,
			long id) {
		super.onListItemClick(listView, vista, posicion, id);
		Intent i = new Intent(this, VistaInmersion.class);
		i.putExtra("id", id);
		startActivityForResult(i, 0);
	}

	@Override
	protected void onResume() {
		super.onResume();
		activarProveedores();
	}

	/*
	 * Proveedores de localizacin Las actualizaciones se programan con un
	 * periodo de 20 y 10 segundos y con una distancia mnima de 5 o 10 m,
	 * dependiendo del proveedor
	 */
	private void activarProveedores() {
		if (manejador.isProviderEnabled(LocationManager.GPS_PROVIDER)) {
			manejador.requestLocationUpdates(LocationManager.GPS_PROVIDER,
					20 * 1000, 5, this);
		}
		if (manejador.isProviderEnabled(LocationManager.NETWORK_PROVIDER)) {
			manejador.requestLocationUpdates(LocationManager.NETWORK_PROVIDER,
					10 * 1000, 10, this);
		}
	}

	@Override
	protected void onPause() {
		super.onPause();
		manejador.removeUpdates(this);
	}

	@Override
	public void onLocationChanged(Location location) {
		actualizaMejorLocaliz(location);
	}

	@Override
	public void onProviderDisabled(String proveedor) {
		activarProveedores();
	}

	@Override
	public void onProviderEnabled(String proveedor) {
		activarProveedores();
	}

	@Override
	public void onStatusChanged(String proveedor, int estado, Bundle extras) {
		activarProveedores();
	}

	/*
	 * En la variable mejorLocaliz almacenamos la mejor localizacin. Esta solo
	 * ser actualizada con la nueva propuesta si: todava no ha sido
	 * inicializada; o la nueva localizacin tiene una precisin aceptable
	 * (almenos la mitad que la actual); o la diferencia de tiempo es superior a
	 * dos minutos. Una vez comprovado si se cumple alguna de las tres
	 * condiciones, actualizamos mejorLocaliz y guardamos la posicin en
	 * Inmersiones.posicionActual.
	 */

	private static final long DOS_MINUTOS = 2 * 60 * 1000;

	private void actualizaMejorLocaliz(Location localiz) {
		if (localiz != null
				&& (mejorLocaliz == null
						|| localiz.getAccuracy() < 2 * mejorLocaliz
								.getAccuracy() || localiz.getTime()
						- mejorLocaliz.getTime() > DOS_MINUTOS)) {
			Log.d(Inmersiones.TAG, "Nueva mejor localizacin");
			mejorLocaliz = localiz;
			Inmersiones.posicionActual.setLatitud(localiz.getLatitude());
			Inmersiones.posicionActual.setLongitud(localiz.getLongitude());
		}
	}
	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);
		actualizaLista();
	}

	public void actualizaLista() {
		ListView listView = (ListView) findViewById(android.R.id.list);
		AdaptadorCursorInmersiones adaptador = (AdaptadorCursorInmersiones) listView
				.getAdapter();
		adaptador.changeCursor(Inmersiones.listado());
	}
}
