package com.proyecto.libroinmersiones;

import java.io.File;
import java.text.DateFormat;
import java.util.Date;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.provider.MediaStore;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ImageView;
import android.widget.RatingBar;
import android.widget.TextView;
import android.widget.RatingBar.OnRatingBarChangeListener;

public class VistaCentroBuceo extends Activity {
	private long id;
	private CentroBuceo centroBuceo;
	private ImageView imageView;
	private Uri uriFoto;
	final static int RESULTADO_EDITAR = 1;
	final static int RESULTADO_GALERIA = 2;
	final static int RESULTADO_FOTO = 3;

	@Override
	protected void onCreate(Bundle savedInstanceState) {

		super.onCreate(savedInstanceState);
		setContentView(R.layout.detalle_centro_buceo);

		Bundle extras = getIntent().getExtras();

		id = extras.getLong("id", -1);

		imageView = (ImageView) findViewById(R.id.foto);
		actualizarVistas();

	}

	// *********** Gestin del Men ******************************//
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.vista_inmersion, menu);
		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {

		switch (item.getItemId()) {
		case R.id.accion_compartir:
			Intent intent = new Intent(Intent.ACTION_SEND);
			intent.setType("text/plain");
			intent.putExtra(Intent.EXTRA_TEXT, centroBuceo.getNombre() + " - "
					+ centroBuceo.getUrl());
			startActivity(intent);
			return true;
		case R.id.accion_llegar:
			verMapa(null);
			return true;
		case R.id.accion_editar:
			Intent i = new Intent(VistaCentroBuceo.this, EdicionCentroBuceo.class);
			i.putExtra("id", id);
			startActivityForResult(i, RESULTADO_EDITAR);
			return true;
		case R.id.accion_borrar:
			confirmarBorrado(null);
			return true;
		default:
			return super.onOptionsItemSelected(item);
		}
	}

	// ************* tomarFoto *****************************************//

	public void tomarFoto(View view) {
		Intent intent = new Intent("android.media.action.IMAGE_CAPTURE");
		uriFoto = Uri.fromFile(new File(Environment
				.getExternalStorageDirectory()
				+ File.separator
				+ "img_"
				+ (System.currentTimeMillis() / 1000) + ".jpg"));
		intent.putExtra(MediaStore.EXTRA_OUTPUT, uriFoto);
		startActivityForResult(intent, RESULTADO_FOTO);
	}

	// ************* verMapa *****************************************//

	public void verMapa(View view) {
		Uri uri;
		double lat = centroBuceo.getPosicion().getLatitud();
		double lon = centroBuceo.getPosicion().getLongitud();
		if (lat != 0 || lon != 0) {
			uri = Uri.parse("geo:" + lat + "," + lon);
		} else {
			uri = Uri.parse("geo:0,0?q=" + centroBuceo.getDireccion());
		}
		Intent intent = new Intent(Intent.ACTION_VIEW, uri);
		startActivity(intent);
	}

	public void llamadaTelefono(View view) {
		startActivity(new Intent(Intent.ACTION_DIAL, Uri.parse("tel:"
				+ centroBuceo.getTelefono())));
	}

	public void pgWeb(View view) {
		startActivity(new Intent(Intent.ACTION_VIEW, Uri.parse(centroBuceo
				.getUrl())));
	}

	public void confirmarBorrado(View v) {
		new AlertDialog.Builder(this)
				.setTitle("Borrado de centroBuceo")
				.setMessage(
						"Ests seguro que quieres eliminar este centroBuceo?")
				.setPositiveButton("Ok", new DialogInterface.OnClickListener() {
					public void onClick(DialogInterface dialog, int whichButton) {
						CentrosBuceo.borrar((int) id);
						finish();
					}
				}).setNegativeButton("Cancelar", null).show();
	}

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		if (requestCode == RESULTADO_EDITAR) {
			imageView = (ImageView) findViewById(R.id.foto);
			actualizarVistas();
			findViewById(R.id.scrollView1).invalidate();
		} else if (requestCode == RESULTADO_GALERIA
				&& resultCode == Activity.RESULT_OK) {
			centroBuceo.setFoto(data.getDataString());
			CentrosBuceo.actualizaCentroBuceo((int) id, centroBuceo);
			ponerFoto(imageView, centroBuceo.getFoto());
		} else if (requestCode == RESULTADO_FOTO
				&& resultCode == Activity.RESULT_OK && centroBuceo != null
				&& uriFoto != null) {
			centroBuceo.setFoto(uriFoto.toString());
			CentrosBuceo.actualizaCentroBuceo((int) id, centroBuceo);
			ponerFoto(imageView, centroBuceo.getFoto());
		}
	}

	public void actualizarVistas() {

		centroBuceo = CentrosBuceo.elemento((int) id);
		TextView nombre = (TextView) findViewById(R.id.nombre);
		nombre.setText(centroBuceo.getNombre());
		ImageView logo_tipo = (ImageView) findViewById(R.id.logo_tipo);
		logo_tipo.setImageResource(centroBuceo.getTipo().getRecurso());

		TextView tipo = (TextView) findViewById(R.id.tipo);
		tipo.setText(centroBuceo.getTipo().getTexto());

		TextView direccion = (TextView) findViewById(R.id.direccion);
		if (centroBuceo.getDireccion() == "") {
			findViewById(R.id.logo_direccion).setVisibility(View.GONE);
			findViewById(R.id.direccion).setVisibility(View.GONE);
		} else {
			direccion.setText(centroBuceo.getDireccion());
		}

		TextView telefono = (TextView) findViewById(R.id.telefono);
		if (centroBuceo.getTelefono() == 0) {
			findViewById(R.id.logo_telefono).setVisibility(View.GONE);
			findViewById(R.id.telefono).setVisibility(View.GONE);
		} else {
			telefono.setText(Integer.toString(centroBuceo.getTelefono()));
		}

		TextView url = (TextView) findViewById(R.id.url);
		if (centroBuceo.getUrl() == "") {
			findViewById(R.id.logo_url).setVisibility(View.GONE);
			findViewById(R.id.url).setVisibility(View.GONE);
		} else {
			url.setText(centroBuceo.getUrl());
		}

		TextView comentario = (TextView) findViewById(R.id.comentario);
		if (centroBuceo.getComentario() == "") {
			findViewById(R.id.logo_comentario).setVisibility(View.GONE);
			findViewById(R.id.comentario).setVisibility(View.GONE);
		} else {
			comentario.setText(centroBuceo.getComentario());
		}

		ponerFoto(imageView, centroBuceo.getFoto());

		TextView fecha = (TextView) findViewById(R.id.fecha);
		fecha.setText(DateFormat.getDateInstance().format(
				new Date(centroBuceo.getFecha())));
		TextView hora = (TextView) findViewById(R.id.hora);
		hora.setText(DateFormat.getTimeInstance().format(
				new Date(centroBuceo.getFecha())));

		RatingBar valoracion = (RatingBar) findViewById(R.id.valoracion);
		valoracion.setRating(centroBuceo.getValoracion());
		valoracion
				.setOnRatingBarChangeListener(new OnRatingBarChangeListener() {
					@Override
					public void onRatingChanged(RatingBar ratingBar,
							float valor, boolean fromUser) {
						centroBuceo.setValoracion(valor);
						CentrosBuceo.actualizaCentroBuceo((int) id, centroBuceo);
					}
				});
	}

	protected void ponerFoto(ImageView imageView, String uri) {
		if (uri != null) {
			imageView.setImageURI(Uri.parse(uri));
		} else {
			imageView.setImageBitmap(null);
		}
	}

	public void galeria(View view) {
		Intent intent = new Intent(Intent.ACTION_GET_CONTENT);
		intent.addCategory(Intent.CATEGORY_OPENABLE);
		intent.setType("image/*");
		startActivityForResult(intent, RESULTADO_GALERIA);
	}

	public void eliminarFoto(View view) {
		centroBuceo.setFoto(null);
		ponerFoto(imageView, null);
		CentrosBuceo.actualizaCentroBuceo((int) id, centroBuceo);
	}
}

