package com.proyecto.libroinmersiones;

import java.io.File;
import java.text.DateFormat;
import java.text.DecimalFormat;
import java.util.Date;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.graphics.Color;
import android.graphics.PorterDuff;
import android.graphics.drawable.LayerDrawable;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.provider.MediaStore;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.RatingBar;
import android.widget.RatingBar.OnRatingBarChangeListener;
import android.widget.TextView;

public class VistaInmersion extends Activity {
	private long id;
	private Inmersion inmersion;
	private ImageView imageView;
	private Uri uriFoto;
	final static int RESULTADO_EDITAR = 1;
	final static int RESULTADO_GALERIA = 2;
	final static int RESULTADO_FOTO = 3;

	@Override
	protected void onCreate(Bundle savedInstanceState) {

		super.onCreate(savedInstanceState);
		setContentView(R.layout.detalle_inmersion);

		Bundle extras = getIntent().getExtras();

		id = extras.getLong("id", -1);

		imageView = (ImageView) findViewById(R.id.foto);
		actualizarVistas();

	}

	// *********** Gestin del Men ******************************//
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.vista_inmersion, menu);
		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {

		switch (item.getItemId()) {
		case R.id.accion_compartir:
			Intent intent = new Intent(Intent.ACTION_SEND);
			intent.setType("text/plain");
			intent.putExtra(Intent.EXTRA_TEXT, inmersion.getNombre() + " - "
					+ inmersion.getPosicion());
			startActivity(intent);
			return true;
		case R.id.accion_llegar:
			verMapa(null);
			return true;
		case R.id.accion_editar:
			Intent i = new Intent(VistaInmersion.this, EdicionInmersion.class);
			i.putExtra("id", id);
			startActivityForResult(i, RESULTADO_EDITAR);
			return true;
		case R.id.accion_borrar:
			// Inmersiones.borrar((int) id);
			confirmarBorrado(null);
			return true;
		default:
			return super.onOptionsItemSelected(item);
		}
	}

	// ************* tomarFoto *****************************************//

	public void tomarFoto(View view) {
		Intent intent = new Intent("android.media.action.IMAGE_CAPTURE");
		uriFoto = Uri.fromFile(new File(Environment
				.getExternalStorageDirectory()
				+ File.separator
				+ "img_"
				+ (System.currentTimeMillis() / 1000) + ".jpg"));
		intent.putExtra(MediaStore.EXTRA_OUTPUT, uriFoto);
		startActivityForResult(intent, RESULTADO_FOTO);
	}

	// ************* verMapa *****************************************//

	public void verMapa(View view) {
		Uri uri;
		double lat = inmersion.getPosicion().getLatitud();
		double lon = inmersion.getPosicion().getLongitud();

		uri = Uri.parse("geo:" + lat + "," + lon + "?q=" + lat + "," + lon);
		/*
		 * if (lat != 0 || lon != 0) { uri = Uri.parse("geo:" + lat + "," +
		 * lon); } else {
		 * 
		 * }
		 */
		Intent intent = new Intent(Intent.ACTION_VIEW, uri);
		startActivity(intent);
	}

	public void confirmarBorrado(View v) {
		new AlertDialog.Builder(this)
				.setTitle("Borrado de inmersion")
				.setMessage(
						"Ests seguro que quieres eliminar este inmersion?")
				.setPositiveButton("Ok", new DialogInterface.OnClickListener() {
					public void onClick(DialogInterface dialog, int whichButton) {
						Inmersiones.borrar((int) id);
						finish();
					}
				}).setNegativeButton("Cancelar", null).show();
	}

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		if (requestCode == RESULTADO_EDITAR) {
			imageView = (ImageView) findViewById(R.id.foto);
			actualizarVistas();
			findViewById(R.id.scrollView1).invalidate();
		} else if (requestCode == RESULTADO_GALERIA
				&& resultCode == Activity.RESULT_OK) {
			inmersion.setFoto(data.getDataString());
			Inmersiones.actualizaInmersion((int) id, inmersion);
			ponerFoto(imageView, inmersion.getFoto());
		} else if (requestCode == RESULTADO_FOTO
				&& resultCode == Activity.RESULT_OK && inmersion != null
				&& uriFoto != null) {
			inmersion.setFoto(uriFoto.toString());
			Inmersiones.actualizaInmersion((int) id, inmersion);
			ponerFoto(imageView, inmersion.getFoto());
		}
	}

	public void actualizarVistas() {

		inmersion = Inmersiones.elemento((int) id);
		TextView nombre = (TextView) findViewById(R.id.nombre);
		nombre.setText(inmersion.getNombre());
		// ImageView logo_tipo = (ImageView) findViewById(R.id.logo_tipo);
		// logo_tipo.setImageResource(inmersion.getTipo().getRecurso());
		TextView situacion = (TextView) findViewById(R.id.situacion);
		situacion.setText(inmersion.getPosicion().toString());
		
		TextView tipoTraje = (TextView) findViewById(R.id.tipo_traje);
		tipoTraje.setText(inmersion.getTipoTraje());

		TextView tipoBotella = (TextView) findViewById(R.id.tipo_botella);
		tipoBotella.setText(inmersion.getTipoBotella());
		
		TextView lastre = (TextView) findViewById(R.id.txt_lastre);
		lastre.setText(String.valueOf(inmersion.getLastre()));
		TextView presionIni = (TextView) findViewById(R.id.presion_inicial);
		presionIni.setText(String.valueOf(inmersion.getPresionIni()));
		TextView presionFin = (TextView) findViewById(R.id.presion_final);
		presionFin.setText(String.valueOf(inmersion.getPresionFinal()));
		TextView tempAire = (TextView) findViewById(R.id.temp_aire);
		tempAire.setText(String.valueOf(inmersion.getTempAire()));
		TextView tempAgua = (TextView) findViewById(R.id.temp_agua);
		tempAgua.setText(String.valueOf(inmersion.getTempAgua()));
		TextView profMax = (TextView) findViewById(R.id.prof_max);
		profMax.setText(String.valueOf(inmersion.getProfMaxima()));
		TextView duracion = (TextView) findViewById(R.id.tpo_buceo);
		duracion.setText(String.valueOf(inmersion.getDuracion()));
		
		TextView comentario = (TextView) findViewById(R.id.comentario);
		if (inmersion.getComentario() == "") {
			findViewById(R.id.logo_comentario).setVisibility(View.GONE);
			findViewById(R.id.comentario).setVisibility(View.GONE);
		} else {
			comentario.setText(inmersion.getComentario());
		}

		ponerFoto(imageView, inmersion.getFoto());

		TextView fecha = (TextView) findViewById(R.id.fecha);
		fecha.setText(DateFormat.getDateInstance().format(
				new Date(inmersion.getFecha())));
		TextView hora = (TextView) findViewById(R.id.hora);
		hora.setText(DateFormat.getTimeInstance().format(
				new Date(inmersion.getFecha())));
		
		
		RatingBar valoracion = (RatingBar) findViewById(R.id.valoracion);
		LayerDrawable stars = (LayerDrawable) valoracion.getProgressDrawable();
		stars.getDrawable(0).setColorFilter(Color.TRANSPARENT, PorterDuff.Mode.SRC_ATOP);
		stars.getDrawable(1).setColorFilter(Color.TRANSPARENT, PorterDuff.Mode.SRC_ATOP);
		stars.getDrawable(2).setColorFilter(Color.YELLOW, PorterDuff.Mode.SRC_ATOP);
		valoracion.setRating(inmersion.getValoracion());
		valoracion
				.setOnRatingBarChangeListener(new OnRatingBarChangeListener() {
					@Override
					public void onRatingChanged(RatingBar ratingBar,
							float valor, boolean fromUser) {
						inmersion.setValoracion(valor);
						Inmersiones.actualizaInmersion((int) id, inmersion);
					}
				});
	}

	protected void ponerFoto(ImageView imageView, String uri) {
		if (uri != null) {
			imageView.setImageURI(Uri.parse(uri));
		} else {
			imageView.setImageBitmap(null);
		}
	}

	public void galeria(View view) {
		Intent intent = new Intent(Intent.ACTION_GET_CONTENT);
		intent.addCategory(Intent.CATEGORY_OPENABLE);
		intent.setType("image/*");
		startActivityForResult(intent, RESULTADO_GALERIA);
	}

	public void eliminarFoto(View view) {
		inmersion.setFoto(null);
		ponerFoto(imageView, null);
		Inmersiones.actualizaInmersion((int) id, inmersion);
	}

}
